==> qtjambi-qt3drender-5.15.9-sources.jar: io/qt/qt3d/render/QGeometry.java <==
package io.qt.qt3d.render;


/**
 * <p>Encapsulates geometry</p>
 * <p>Java wrapper for Qt class <a href="http://doc.qt.io/qt-5/qt3drender-qgeometry.html">Qt3DRender::QGeometry</a></p>
 */
public class QGeometry extends io.qt.qt3d.core.QNode
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    @io.qt.QtPropertyMember(enabled=false)
    private Object __rcBoundingVolumePositionAttribute = null;
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QGeometry.class);
    

    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qgeometry.html#boundingVolumePositionAttribute-prop">Qt3DRender::QGeometry::boundingVolumePositionAttributeChanged(Qt3DRender::QAttribute*)</a></p>
     */
    @io.qt.QtPropertyNotify(name="boundingVolumePositionAttribute")
    public final Signal1<io.qt.qt3d.render.QAttribute> boundingVolumePositionAttributeChanged = new Signal1<>();

    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qgeometry.html#maxExtent-prop">Qt3DRender::QGeometry::maxExtentChanged(QVector3D)</a></p>
     */
    @io.qt.QtPropertyNotify(name="maxExtent")
    public final Signal1<io.qt.gui.QVector3D> maxExtentChanged = new Signal1<>();

    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qgeometry.html#minExtent-prop">Qt3DRender::QGeometry::minExtentChanged(QVector3D)</a></p>
     */
    @io.qt.QtPropertyNotify(name="minExtent")
    public final Signal1<io.qt.gui.QVector3D> minExtentChanged = new Signal1<>();
    
    /**
     * <p>Overloaded constructor for {@link #QGeometry(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QGeometry() {
        this((io.qt.qt3d.core.QNode)null);
    }
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qgeometry.html#QGeometry">Qt3DRender::QGeometry::QGeometry(Qt3DCore::QNode*)</a></p>
     */
    @SuppressWarnings({"exports"})
    public QGeometry(io.qt.qt3d.core.QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QGeometry instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qgeometry.html#addAttribute">Qt3DRender::QGeometry::addAttribute(Qt3DRender::QAttribute*)</a></p>
     */
    public final void addAttribute(io.qt.qt3d.render.QAttribute attribute){
        addAttribute_native_Qt3DRender_QAttribute_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(attribute));
    }
    
    private native void addAttribute_native_Qt3DRender_QAttribute_ptr(long __this__nativeId, long attribute);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qgeometry.html#attributes">Qt3DRender::QGeometry::attributes()const</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.core.QVector<io.qt.qt3d.render.QAttribute> attributes(){
        return attributes_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.core.QVector<io.qt.qt3d.render.QAttribute> attributes_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qgeometry.html#boundingVolumePositionAttribute-prop">Qt3DRender::QGeometry::boundingVolumePositionAttribute()const</a></p>
     */
    @io.qt.QtPropertyReader(name="boundingVolumePositionAttribute")
    @io.qt.QtUninvokable
    public final io.qt.qt3d.render.QAttribute boundingVolumePositionAttribute(){
        return boundingVolumePositionAttribute_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.qt3d.render.QAttribute boundingVolumePositionAttribute_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qgeometry.html#maxExtent-prop">Qt3DRender::QGeometry::maxExtent()const</a></p>
     */
    @io.qt.QtPropertyReader(name="maxExtent")
    @io.qt.QtUninvokable
    public final io.qt.gui.QVector3D maxExtent(){
        return maxExtent_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.gui.QVector3D maxExtent_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qgeometry.html#minExtent-prop">Qt3DRender::QGeometry::minExtent()const</a></p>
     */
    @io.qt.QtPropertyReader(name="minExtent")
    @io.qt.QtUninvokable
    public final io.qt.gui.QVector3D minExtent(){
        return minExtent_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.gui.QVector3D minExtent_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qgeometry.html#removeAttribute">Qt3DRender::QGeometry::removeAttribute(Qt3DRender::QAttribute*)</a></p>
     */
    public final void removeAttribute(io.qt.qt3d.render.QAttribute attribute){
        removeAttribute_native_Qt3DRender_QAttribute_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(attribute));
    }
    
    private native void removeAttribute_native_Qt3DRender_QAttribute_ptr(long __this__nativeId, long attribute);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qgeometry.html#boundingVolumePositionAttribute-prop">Qt3DRender::QGeometry::setBoundingVolumePositionAttribute(Qt3DRender::QAttribute*)</a></p>
     */
    @io.qt.QtPropertyWriter(name="boundingVolumePositionAttribute")
    public final void setBoundingVolumePositionAttribute(io.qt.qt3d.render.QAttribute boundingVolumePositionAttribute){
        setBoundingVolumePositionAttribute_native_Qt3DRender_QAttribute_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(boundingVolumePositionAttribute));
        __rcBoundingVolumePositionAttribute = boundingVolumePositionAttribute;
    }
    
    private native void setBoundingVolumePositionAttribute_native_Qt3DRender_QAttribute_ptr(long __this__nativeId, long boundingVolumePositionAttribute);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qnode-obsolete.html#sceneChangeEvent">Qt3DCore::QNode::sceneChangeEvent(Qt3DCore::QSceneChangePtr)</a></p>
     */
    @io.qt.QtUninvokable
    protected void sceneChangeEvent(io.qt.qt3d.core.QSceneChange change){
        sceneChangeEvent_native_cref_QSharedPointer(QtJambi_LibraryUtilities.internal.nativeId(this), change);
    }
    
    @io.qt.QtUninvokable
    private native void sceneChangeEvent_native_cref_QSharedPointer(long __this__nativeId, io.qt.qt3d.core.QSceneChange change);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QGeometry(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QGeometry(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QGeometry instance, QDeclarativeConstructor constructor);
    
}

==> qtjambi-qt3drender-5.15.13-sources.jar: io/qt/qt3d/render/QGeometry.java <==
package io.qt.qt3d.render;


/**
 * <p>Encapsulates geometry</p>
 * <p>Java wrapper for Qt's class <a href="http://doc.qt.io/qt-5/qt3drender-qgeometry.html">Qt3DRender::QGeometry</a></p>
 */
public class QGeometry extends io.qt.qt3d.core.QNode
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    @io.qt.QtPropertyMember(enabled=false)
    private Object __rcBoundingVolumePositionAttribute = null;
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QGeometry.class);
    

    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qgeometry.html#boundingVolumePositionAttribute-prop">Qt3DRender::QGeometry::boundingVolumePositionAttributeChanged(Qt3DRender::QAttribute*)</a></p>
     */
    @io.qt.QtPropertyNotify(name="boundingVolumePositionAttribute")
    public final Signal1<io.qt.qt3d.render.QAttribute> boundingVolumePositionAttributeChanged = new Signal1<>();

    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qgeometry.html#maxExtent-prop">Qt3DRender::QGeometry::maxExtentChanged(QVector3D)</a></p>
     */
    @io.qt.QtPropertyNotify(name="maxExtent")
    public final Signal1<io.qt.gui.QVector3D> maxExtentChanged = new Signal1<>();

    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qgeometry.html#minExtent-prop">Qt3DRender::QGeometry::minExtentChanged(QVector3D)</a></p>
     */
    @io.qt.QtPropertyNotify(name="minExtent")
    public final Signal1<io.qt.gui.QVector3D> minExtentChanged = new Signal1<>();
    
    /**
     * <p>Overloaded constructor for {@link #QGeometry(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QGeometry() {
        this((io.qt.qt3d.core.QNode)null);
    }
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qgeometry.html#QGeometry">Qt3DRender::QGeometry::QGeometry(Qt3DCore::QNode*)</a></p>
     */
    @SuppressWarnings({"exports"})
    public QGeometry(io.qt.qt3d.core.QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QGeometry instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qgeometry.html#addAttribute">Qt3DRender::QGeometry::addAttribute(Qt3DRender::QAttribute*)</a></p>
     */
    public final void addAttribute(io.qt.qt3d.render.QAttribute attribute){
        addAttribute_native_Qt3DRender_QAttribute_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(attribute));
    }
    
    private native void addAttribute_native_Qt3DRender_QAttribute_ptr(long __this__nativeId, long attribute);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qgeometry.html#attributes">Qt3DRender::QGeometry::attributes()const</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.core.QVector<io.qt.qt3d.render.QAttribute> attributes(){
        return attributes_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.core.QVector<io.qt.qt3d.render.QAttribute> attributes_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qgeometry.html#boundingVolumePositionAttribute-prop">Qt3DRender::QGeometry::boundingVolumePositionAttribute()const</a></p>
     */
    @io.qt.QtPropertyReader(name="boundingVolumePositionAttribute")
    @io.qt.QtUninvokable
    public final io.qt.qt3d.render.QAttribute boundingVolumePositionAttribute(){
        return boundingVolumePositionAttribute_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.qt3d.render.QAttribute boundingVolumePositionAttribute_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qgeometry.html#maxExtent-prop">Qt3DRender::QGeometry::maxExtent()const</a></p>
     */
    @io.qt.QtPropertyReader(name="maxExtent")
    @io.qt.QtUninvokable
    public final io.qt.gui.QVector3D maxExtent(){
        return maxExtent_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.gui.QVector3D maxExtent_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qgeometry.html#minExtent-prop">Qt3DRender::QGeometry::minExtent()const</a></p>
     */
    @io.qt.QtPropertyReader(name="minExtent")
    @io.qt.QtUninvokable
    public final io.qt.gui.QVector3D minExtent(){
        return minExtent_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.gui.QVector3D minExtent_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qgeometry.html#removeAttribute">Qt3DRender::QGeometry::removeAttribute(Qt3DRender::QAttribute*)</a></p>
     */
    public final void removeAttribute(io.qt.qt3d.render.QAttribute attribute){
        removeAttribute_native_Qt3DRender_QAttribute_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(attribute));
    }
    
    private native void removeAttribute_native_Qt3DRender_QAttribute_ptr(long __this__nativeId, long attribute);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qgeometry.html#boundingVolumePositionAttribute-prop">Qt3DRender::QGeometry::setBoundingVolumePositionAttribute(Qt3DRender::QAttribute*)</a></p>
     */
    @io.qt.QtPropertyWriter(name="boundingVolumePositionAttribute")
    public final void setBoundingVolumePositionAttribute(io.qt.qt3d.render.QAttribute boundingVolumePositionAttribute){
        setBoundingVolumePositionAttribute_native_Qt3DRender_QAttribute_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(boundingVolumePositionAttribute));
        __rcBoundingVolumePositionAttribute = boundingVolumePositionAttribute;
    }
    
    private native void setBoundingVolumePositionAttribute_native_Qt3DRender_QAttribute_ptr(long __this__nativeId, long boundingVolumePositionAttribute);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qnode-obsolete.html#sceneChangeEvent">Qt3DCore::QNode::sceneChangeEvent(Qt3DCore::QSceneChangePtr)</a></p>
     */
    @io.qt.QtUninvokable
    protected void sceneChangeEvent(io.qt.qt3d.core.QSceneChange change){
        sceneChangeEvent_native_cref_QSharedPointer(QtJambi_LibraryUtilities.internal.nativeId(this), change);
    }
    
    @io.qt.QtUninvokable
    private native void sceneChangeEvent_native_cref_QSharedPointer(long __this__nativeId, io.qt.qt3d.core.QSceneChange change);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QGeometry(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QGeometry(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QGeometry instance, QDeclarativeConstructor constructor);
    
}
